==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/ddf/autoreplace__widget_8h.js <==
var autoreplace__widget_8h =
[
    [ "ReplaceVehicleWidgets", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665e", [
      [ "WID_RV_CAPTION", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea173e0f04445eb96e6fbb342ff83305f8", null ],
      [ "WID_RV_SORT_ASCENDING_DESCENDING", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eac3ae1392b1895b115cba1661aaa6d67d", null ],
      [ "WID_RV_SHOW_HIDDEN_ENGINES", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea03c71635fe262dc414e826c72d3aef07", null ],
      [ "WID_RV_SORT_DROPDOWN", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eaf2f2510c2346e74f19803ed641294fdd", null ],
      [ "WID_RV_LEFT_MATRIX", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eabeda36af4d0f7ac7963025dbd78dca32", null ],
      [ "WID_RV_LEFT_SCROLLBAR", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea0f221b551816453660fa83c078be3484", null ],
      [ "WID_RV_RIGHT_MATRIX", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea77bec01d50af883ff13b821d92354aec", null ],
      [ "WID_RV_RIGHT_SCROLLBAR", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eac68b3f07f2f54dded8db98be42a72b40", null ],
      [ "WID_RV_LEFT_DETAILS", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eaf7524da7a5ce8b7d4e23516716ae4e27", null ],
      [ "WID_RV_RIGHT_DETAILS", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea2d9d6e090b15c0a8a6ea50aaafc1b2ec", null ],
      [ "WID_RV_START_REPLACE", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eaf0da5101c8cb75617733c64e62598a9c", null ],
      [ "WID_RV_INFO_TAB", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea8a2a6a204fc838526bb4dfc0d88d0572", null ],
      [ "WID_RV_STOP_REPLACE", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea4ce1900de58d237aadd1aa56bc9f2d88", null ],
      [ "WID_RV_TRAIN_ENGINEWAGON_DROPDOWN", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea0e18862c2ae23eb2537548738cd95028", null ],
      [ "WID_RV_TRAIN_RAILTYPE_DROPDOWN", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea4cdd173bf34e21890ad43241826f8eaf", null ],
      [ "WID_RV_TRAIN_WAGONREMOVE_TOGGLE", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea37c8f7f118d55aacbee5d675f1a030c8", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/ddf/autoreplace__widget_8h.js <==
var autoreplace__widget_8h =
[
    [ "ReplaceVehicleWidgets", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665e", [
      [ "WID_RV_CAPTION", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea173e0f04445eb96e6fbb342ff83305f8", null ],
      [ "WID_RV_SORT_ASCENDING_DESCENDING", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eac3ae1392b1895b115cba1661aaa6d67d", null ],
      [ "WID_RV_SHOW_HIDDEN_ENGINES", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea03c71635fe262dc414e826c72d3aef07", null ],
      [ "WID_RV_SORT_DROPDOWN", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eaf2f2510c2346e74f19803ed641294fdd", null ],
      [ "WID_RV_LEFT_MATRIX", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eabeda36af4d0f7ac7963025dbd78dca32", null ],
      [ "WID_RV_LEFT_SCROLLBAR", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea0f221b551816453660fa83c078be3484", null ],
      [ "WID_RV_RIGHT_MATRIX", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea77bec01d50af883ff13b821d92354aec", null ],
      [ "WID_RV_RIGHT_SCROLLBAR", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eac68b3f07f2f54dded8db98be42a72b40", null ],
      [ "WID_RV_LEFT_DETAILS", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eaf7524da7a5ce8b7d4e23516716ae4e27", null ],
      [ "WID_RV_RIGHT_DETAILS", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea2d9d6e090b15c0a8a6ea50aaafc1b2ec", null ],
      [ "WID_RV_START_REPLACE", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eaf0da5101c8cb75617733c64e62598a9c", null ],
      [ "WID_RV_INFO_TAB", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea8a2a6a204fc838526bb4dfc0d88d0572", null ],
      [ "WID_RV_STOP_REPLACE", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea4ce1900de58d237aadd1aa56bc9f2d88", null ],
      [ "WID_RV_RAIL_ROAD_TYPE_DROPDOWN", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665eab6ea3bc4b9d09561dcb5c439ac668b18", null ],
      [ "WID_RV_TRAIN_ENGINEWAGON_DROPDOWN", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea0e18862c2ae23eb2537548738cd95028", null ],
      [ "WID_RV_TRAIN_WAGONREMOVE_TOGGLE", "d1/ddf/autoreplace__widget_8h.html#a9c30fafeda97884acb5a98ab6f9b665ea37c8f7f118d55aacbee5d675f1a030c8", null ]
    ] ]
];
